@@ -817,16 +817,20 @@ contact_list_view_text_cell_data_func (GtkTreeViewColumn     *tree_column,
 	gboolean is_group;
 	gboolean is_active;
 	gboolean show_status;
+	gchar *name;
 
 	gtk_tree_model_get (model, iter,
 			    EMPATHY_CONTACT_LIST_STORE_COL_IS_GROUP, &is_group,
 			    EMPATHY_CONTACT_LIST_STORE_COL_IS_ACTIVE, &is_active,
 			    EMPATHY_CONTACT_LIST_STORE_COL_STATUS_VISIBLE, &show_status,
+			    EMPATHY_CONTACT_LIST_STORE_COL_NAME, &name,
 			    -1);
 
 	g_object_set (cell,
 		      "show-status", show_status,
+		      "text", name,
 		      NULL);
+	g_free (name);
 
 	contact_list_view_cell_set_background (view, cell, is_group, is_active);
 }
