@@ -56,6 +56,8 @@ typedef struct {
 	gboolean              page_loaded;
 	GList                *message_queue;
 	gchar                *hovered_uri;
+	guint                 notify_enable_webkit_developer_tools_id;
+	GtkWidget            *inspector_window;
 } EmpathyThemeAdiumPriv;
 
 struct _EmpathyAdiumData {
@@ -99,6 +101,34 @@ G_DEFINE_TYPE_WITH_CODE (EmpathyThemeAdium, empathy_theme_adium,
 			 G_IMPLEMENT_INTERFACE (EMPATHY_TYPE_CHAT_VIEW,
 						theme_adium_iface_init));
 
+static void
+theme_adium_update_enable_webkit_developer_tools (EmpathyThemeAdium *theme)
+{
+	WebKitWebView  *web_view = WEBKIT_WEB_VIEW (theme);
+	gboolean        enable_webkit_developer_tools;
+
+	if (!empathy_conf_get_bool (empathy_conf_get (),
+				    EMPATHY_PREFS_CHAT_WEBKIT_DEVELOPER_TOOLS,
+				    &enable_webkit_developer_tools)) {
+		return;
+	}
+
+	g_object_set (G_OBJECT (webkit_web_view_get_settings (web_view)),
+		      "enable-developer-extras",
+		      enable_webkit_developer_tools,
+		      NULL);
+}
+
+static void
+theme_adium_notify_enable_webkit_developer_tools_cb (EmpathyConf *conf,
+						     const gchar *key,
+						     gpointer     user_data)
+{
+	EmpathyThemeAdium  *theme = user_data;
+
+	theme_adium_update_enable_webkit_developer_tools (theme);
+}
+
 static WebKitNavigationResponse
 theme_adium_navigation_requested_cb (WebKitWebView        *view,
 				     WebKitWebFrame       *frame,
@@ -157,11 +187,14 @@ theme_adium_populate_popup_cb (WebKitWebView *view,
 			       GtkMenu       *menu,
 			       gpointer       user_data)
 {
-	GtkWidget *item;
-	GList     *items;
-	GtkWidget *icon;
-	gchar     *stock_id;
-	gboolean   is_link = FALSE;
+	EmpathyThemeAdium     *theme = EMPATHY_THEME_ADIUM (view);
+	EmpathyThemeAdiumPriv *priv = GET_PRIV (theme);
+	GtkWidget             *item;
+	GList                 *items;
+	GtkWidget             *icon;
+	gchar                 *stock_id;
+	gboolean               is_link = FALSE;
+	gboolean               developer_tools_enabled;
 
 	/* FIXME: WebKitGTK+'s context menu API clearly needs an
 	 * overhaul.  There is currently no way to know what is being
@@ -176,13 +209,16 @@ theme_adium_populate_popup_cb (WebKitWebView *view,
 		icon = gtk_image_menu_item_get_image (GTK_IMAGE_MENU_ITEM (item));
 		gtk_image_get_stock (GTK_IMAGE (icon), &stock_id, NULL);
 
-		if (!strcmp (stock_id, GTK_STOCK_OPEN))
+		if ((!strcmp (stock_id, GTK_STOCK_OPEN)) && priv->hovered_uri)
 			is_link = TRUE;
 	}
 
 	/* Remove default menu items */
-	gtk_container_foreach (GTK_CONTAINER (menu),
-		(GtkCallback) gtk_widget_destroy, NULL);
+	g_object_get (G_OBJECT (webkit_web_view_get_settings (view)),
+		      "enable-developer-extras", &developer_tools_enabled, NULL);
+	if (!developer_tools_enabled)
+		gtk_container_foreach (GTK_CONTAINER (menu),
+				       (GtkCallback) gtk_widget_destroy, NULL);
 
 	/* Select all item */
 	item = gtk_image_menu_item_new_from_stock (GTK_STOCK_SELECT_ALL, NULL);
@@ -821,6 +857,9 @@ theme_adium_finalize (GObject *object)
 	empathy_adium_data_unref (priv->data);
 	g_free (priv->hovered_uri);
 
+	empathy_conf_notify_remove (empathy_conf_get (),
+				    priv->notify_enable_webkit_developer_tools_id);
+
 	G_OBJECT_CLASS (empathy_theme_adium_parent_class)->finalize (object);
 }
 
@@ -839,9 +878,79 @@ theme_adium_dispose (GObject *object)
 		priv->last_contact = NULL;
 	}
 
+	if (priv->inspector_window) {
+		gtk_widget_destroy (priv->inspector_window);
+		priv->inspector_window = NULL;
+	}
+
 	G_OBJECT_CLASS (empathy_theme_adium_parent_class)->dispose (object);
 }
 
+static gboolean
+theme_adium_inspector_show_window_cb (WebKitWebInspector *inspector,
+				      EmpathyThemeAdium  *theme)
+{
+	EmpathyThemeAdiumPriv *priv = GET_PRIV (theme);
+
+	if (priv->inspector_window) {
+		gtk_widget_show_all (priv->inspector_window);
+	}
+
+	return TRUE;
+}
+
+static gboolean
+theme_adium_inspector_close_window_cb (WebKitWebInspector *inspector,
+				       EmpathyThemeAdium  *theme)
+{
+	EmpathyThemeAdiumPriv *priv = GET_PRIV (theme);
+
+	if (priv->inspector_window) {
+		gtk_widget_hide (priv->inspector_window);
+	}
+
+	return TRUE;
+}
+
+static WebKitWebView *
+theme_adium_inspect_web_view_cb (WebKitWebInspector *inspector,
+				 WebKitWebView      *web_view,
+				 EmpathyThemeAdium  *theme)
+{
+	EmpathyThemeAdiumPriv *priv = GET_PRIV (theme);
+	GtkWidget             *scrolled_window;
+	GtkWidget             *inspector_web_view;
+
+	if (!priv->inspector_window) {
+		/* Create main window */
+		priv->inspector_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+		gtk_window_set_default_size (GTK_WINDOW (priv->inspector_window),
+					     800, 600);
+		g_signal_connect (priv->inspector_window, "delete-event",
+				  G_CALLBACK (gtk_widget_hide_on_delete), NULL);
+
+		/* Pack a scrolled window */
+		scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
+						GTK_POLICY_AUTOMATIC,
+						GTK_POLICY_AUTOMATIC);
+		gtk_container_add (GTK_CONTAINER (priv->inspector_window),
+				   scrolled_window);
+		gtk_widget_show  (scrolled_window);
+
+		/* Pack a webview in the scrolled window. That webview will be
+		 * used to render the inspector tool.  */
+		inspector_web_view = webkit_web_view_new ();
+		gtk_container_add (GTK_CONTAINER (scrolled_window),
+				   inspector_web_view);
+		gtk_widget_show (scrolled_window);
+
+		return WEBKIT_WEB_VIEW (inspector_web_view);
+	}
+
+	return NULL;
+}
+
 static void
 theme_adium_constructed (GObject *object)
 {
@@ -849,27 +958,42 @@ theme_adium_constructed (GObject *object)
 	gchar                 *basedir_uri;
 	const gchar           *font_family = NULL;
 	gint                   font_size = 0;
+	WebKitWebView         *webkit_view = WEBKIT_WEB_VIEW (object);
 	WebKitWebSettings     *webkit_settings;
+	WebKitWebInspector    *webkit_inspector;
 
 	/* Set default settings */
 	font_family = tp_asv_get_string (priv->data->info, "DefaultFontFamily");
 	font_size = tp_asv_get_int32 (priv->data->info, "DefaultFontSize", NULL);
-	webkit_settings = webkit_web_settings_new ();
+	webkit_settings = webkit_web_view_get_settings (webkit_view);
 	if (font_family) {
-		g_object_set (G_OBJECT (webkit_settings), "default-font-family", font_family, NULL);
+		g_object_set (webkit_settings,
+			      "default-font-family", font_family,
+			      NULL);
 	}
 	if (font_size) {
-		g_object_set (G_OBJECT (webkit_settings), "default-font-size", font_size, NULL);
+		g_object_set (webkit_settings,
+			      "default-font-size", font_size,
+			      NULL);
 	}
-	webkit_web_view_set_settings (WEBKIT_WEB_VIEW (object), webkit_settings);
+
+	/* Setup webkit inspector */
+	webkit_inspector = webkit_web_view_get_inspector (webkit_view);
+	g_signal_connect (webkit_inspector, "inspect-web-view",
+			  G_CALLBACK (theme_adium_inspect_web_view_cb),
+			  object);
+	g_signal_connect (webkit_inspector, "show-window",
+			  G_CALLBACK (theme_adium_inspector_show_window_cb),
+			  object);
+	g_signal_connect (webkit_inspector, "close-window",
+			  G_CALLBACK (theme_adium_inspector_close_window_cb),
+			  object);
 
 	/* Load template */
 	basedir_uri = g_strconcat ("file://", priv->data->basedir, NULL);
 	webkit_web_view_load_html_string (WEBKIT_WEB_VIEW (object),
 					  priv->data->template_html,
 					  basedir_uri);
-
-	g_object_unref (webkit_settings);
 	g_free (basedir_uri);
 }
 
@@ -931,7 +1055,6 @@ empathy_theme_adium_class_init (EmpathyThemeAdiumClass *klass)
 							      G_PARAM_READWRITE |
 							      G_PARAM_STATIC_STRINGS));
 
-
 	g_type_class_add_private (object_class, sizeof (EmpathyThemeAdiumPriv));
 }
 
@@ -957,6 +1080,14 @@ empathy_theme_adium_init (EmpathyThemeAdium *theme)
 	g_signal_connect (theme, "hovering-over-link",
 			  G_CALLBACK (theme_adium_hovering_over_link_cb),
 			  NULL);
+
+	priv->notify_enable_webkit_developer_tools_id =
+		empathy_conf_notify_add (empathy_conf_get (),
+					 EMPATHY_PREFS_CHAT_WEBKIT_DEVELOPER_TOOLS,
+					 theme_adium_notify_enable_webkit_developer_tools_cb,
+					 theme);
+
+	theme_adium_update_enable_webkit_developer_tools (theme);
 }
 
 EmpathyThemeAdium *
