@@ -25,14 +25,14 @@
 #ifndef __EMPATHY_ACCOUNTS_DIALOG_H__
 #define __EMPATHY_ACCOUNTS_DIALOG_H__
 
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
-#include <libmissioncontrol/mc-account.h>
+#include <libempathy/empathy-account.h>
 
 G_BEGIN_DECLS
 
 GtkWidget *empathy_accounts_dialog_show (GtkWindow *parent,
-					 McAccount *selected_account);
+					 EmpathyAccount *selected_account);
 
 G_END_DECLS
 
