@@ -13,13 +13,14 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  *
  * Authors: Jonny Lamb <jonny.lamb@collabora.co.uk>
  */
 
 #include <gtk/gtk.h>
+#include <libmissioncontrol/mc-profile.h>
 
 #ifndef __EMPATHY_IMPORT_DIALOG_H__
 #define __EMPATHY_IMPORT_DIALOG_H__
@@ -32,10 +33,13 @@ typedef struct
   GHashTable *settings;
   /* The profile to use for this account */
   McProfile *profile;
+  /* The name of the account import source */
+  gchar *source;
 } EmpathyImportAccountData;
 
-EmpathyImportAccountData *empathy_import_account_data_new (void);
+EmpathyImportAccountData *empathy_import_account_data_new (const gchar *source);
 void empathy_import_account_data_free (EmpathyImportAccountData *data);
+gboolean empathy_import_dialog_accounts_to_import (void);
 void empathy_import_dialog_show (GtkWindow *parent, gboolean warning);
 
 G_END_DECLS
